@@ -10,7 +10,7 @@ use std::borrow::Cow;
 
 use crate::attrs::{AttrItem, ExportInfo, ExportScope, ExportedParams};
 use crate::function::ExportedFn;
-use crate::rhai_module::ExportedConst;
+use crate::rhai_module::{ExportedConst, ExportedType};
 
 #[derive(Debug, Clone, Eq, PartialEq, Hash, Default)]
 pub struct ExportedModParams {
@@ -69,7 +69,7 @@ impl ExportedParams for ExportedModParams {
                 ("export_all", Some(s)) => {
                     return Err(syn::Error::new(s.span(), "extraneous value"))
                 }
-                (attr, _) => {
+                (attr, ..) => {
                     return Err(syn::Error::new(
                         key.span(),
                         format!("unknown attribute '{}'", attr),
@@ -89,8 +89,9 @@ impl ExportedParams for ExportedModParams {
 #[derive(Debug)]
 pub struct Module {
     mod_all: syn::ItemMod,
-    fns: Vec<ExportedFn>,
     consts: Vec<ExportedConst>,
+    custom_types: Vec<ExportedType>,
+    fns: Vec<ExportedFn>,
     sub_modules: Vec<Module>,
     params: ExportedModParams,
 }
@@ -107,9 +108,10 @@ impl Parse for Module {
         let mut mod_all: syn::ItemMod = input.parse()?;
         let fns: Vec<_>;
         let mut consts = Vec::new();
+        let mut custom_types = Vec::new();
         let mut sub_modules = Vec::new();
 
-        if let Some((_, ref mut content)) = mod_all.content {
+        if let Some((.., ref mut content)) = mod_all.content {
             // Gather and parse functions.
             fns = content
                 .iter_mut()
@@ -127,7 +129,7 @@ impl Parse for Module {
                             f.set_cfg_attrs(crate::attrs::collect_cfg_attr(&item_fn.attrs));
 
                             #[cfg(feature = "metadata")]
-                            f.set_comments(crate::attrs::doc_attributes(&mut item_fn.attrs)?);
+                            f.set_comments(crate::attrs::doc_attributes(&item_fn.attrs)?);
                             Ok(f)
                         })?;
 
@@ -138,18 +140,35 @@ impl Parse for Module {
             for item in content.iter() {
                 match item {
                     syn::Item::Const(syn::ItemConst {
-                        vis,
+                        vis: syn::Visibility::Public(..),
                         ref expr,
                         ident,
                         attrs,
                         ty,
                         ..
-                    }) if matches!(vis, syn::Visibility::Public(_)) => consts.push((
-                        ident.to_string(),
-                        ty.clone(),
-                        expr.as_ref().clone(),
-                        crate::attrs::collect_cfg_attr(&attrs),
-                    )),
+                    }) => consts.push(ExportedConst {
+                        name: ident.to_string(),
+                        typ: ty.clone(),
+                        expr: expr.as_ref().clone(),
+                        cfg_attrs: crate::attrs::collect_cfg_attr(&attrs),
+                    }),
+                    _ => {}
+                }
+            }
+            // Gather and parse type definitions.
+            for item in content.iter() {
+                match item {
+                    syn::Item::Type(syn::ItemType {
+                        vis: syn::Visibility::Public(..),
+                        ident,
+                        attrs,
+                        ty,
+                        ..
+                    }) => custom_types.push(ExportedType {
+                        name: ident.to_string(),
+                        typ: ty.clone(),
+                        cfg_attrs: crate::attrs::collect_cfg_attr(&attrs),
+                    }),
                     _ => {}
                 }
             }
@@ -161,7 +180,7 @@ impl Parse for Module {
             let mut i = 0;
             while i < content.len() {
                 match content[i] {
-                    syn::Item::Mod(_) => {
+                    syn::Item::Mod(..) => {
                         let mut item_mod = match content.remove(i) {
                             syn::Item::Mod(m) => m,
                             _ => unreachable!(),
@@ -186,6 +205,7 @@ impl Parse for Module {
             mod_all,
             fns,
             consts,
+            custom_types,
             sub_modules,
             params: ExportedModParams::default(),
         })
@@ -211,10 +231,10 @@ impl Module {
 
     pub fn update_scope(&mut self, parent_scope: &ExportScope) {
         let keep = match (self.params.skip, parent_scope) {
-            (true, _) => false,
-            (_, ExportScope::PubOnly) => matches!(self.mod_all.vis, syn::Visibility::Public(_)),
-            (_, ExportScope::Prefix(s)) => self.mod_all.ident.to_string().starts_with(s),
-            (_, ExportScope::All) => true,
+            (true, ..) => false,
+            (.., ExportScope::PubOnly) => matches!(self.mod_all.vis, syn::Visibility::Public(..)),
+            (.., ExportScope::Prefix(s)) => self.mod_all.ident.to_string().starts_with(s),
+            (.., ExportScope::All) => true,
         };
         self.params.skip = !keep;
     }
@@ -239,13 +259,14 @@ impl Module {
             mut mod_all,
             mut fns,
             consts,
+            custom_types,
             mut sub_modules,
             params,
             ..
         } = self;
         let mod_vis = mod_all.vis;
         let mod_name = mod_all.ident.clone();
-        let (_, orig_content) = mod_all.content.take().unwrap();
+        let (.., orig_content) = mod_all.content.take().unwrap();
         let mod_attrs = mem::take(&mut mod_all.attrs);
 
         if !params.skip {
@@ -255,6 +276,7 @@ impl Module {
             let mod_gen = crate::rhai_module::generate_body(
                 &mut fns,
                 &consts,
+                &custom_types,
                 &mut sub_modules,
                 &params.scope,
             );
@@ -262,7 +284,7 @@ impl Module {
             // NB: sub-modules must have their new items for exporting generated in depth-first order
             // to avoid issues caused by re-parsing them
             let inner_modules = sub_modules
-                .drain(..)
+                .into_iter()
                 .try_fold::<_, _, Result<_, syn::Error>>(Vec::new(), |mut acc, m| {
                     acc.push(m.generate_inner()?);
                     Ok(acc)
@@ -298,6 +320,11 @@ impl Module {
         &self.consts
     }
 
+    #[allow(dead_code)]
+    pub fn custom_types(&self) -> &[ExportedType] {
+        &self.custom_types
+    }
+
     #[allow(dead_code)]
     pub fn fns(&self) -> &[ExportedFn] {
         &self.fns
@@ -312,7 +339,7 @@ impl Module {
     pub fn content(&self) -> Option<&[syn::Item]> {
         match self.mod_all {
             syn::ItemMod {
-                content: Some((_, ref vec)),
+                content: Some((.., ref vec)),
                 ..
             } => Some(vec),
             _ => None,
