@@ -126,7 +126,7 @@ mod function_tests {
         let err = syn::parse2::<ExportedFn>(input_tokens).unwrap_err();
         assert_eq!(
             format!("{}", err),
-            "this type in this position passes from Rhai by value"
+            "function parameters other than the first one cannot be passed by reference"
         );
     }
 
@@ -139,7 +139,7 @@ mod function_tests {
         let err = syn::parse2::<ExportedFn>(input_tokens).unwrap_err();
         assert_eq!(
             format!("{}", err),
-            "this type in this position passes from Rhai by value"
+            "function parameters other than the first one cannot be passed by reference"
         );
     }
 
@@ -486,7 +486,7 @@ mod generate_tests {
                     #[inline(always)]
                     fn call(&self, context: NativeCallContext, args: &mut [&mut Dynamic]) -> RhaiResult {
                         if args[0usize].is_read_only() {
-                            return EvalAltResult::ErrorAssignmentToConstant("x".to_string(), Position::NONE).into();
+                            return Err(EvalAltResult::ErrorAssignmentToConstant("x".to_string(), Position::NONE).into());
                         }
                         let arg1 = mem::take(args[1usize]).cast::<usize>();
                         let arg0 = &mut args[0usize].write_lock::<usize>().unwrap();
