@@ -38,6 +38,32 @@ mod module_tests {
     }
 
     #[test]
+    fn one_factory_fn_with_custom_type_module() {
+        let input_tokens: TokenStream = quote! {
+            pub mod one_fn {
+                pub type Hello = ();
+
+                pub fn get_mystic_number() -> INT {
+                    42
+                }
+            }
+        };
+
+        let item_mod = syn::parse2::<Module>(input_tokens).unwrap();
+        assert!(item_mod.consts().is_empty());
+        assert_eq!(item_mod.custom_types().len(), 1);
+        assert_eq!(item_mod.custom_types()[0].name.to_string(), "Hello");
+        assert_eq!(item_mod.fns().len(), 1);
+        assert_eq!(item_mod.fns()[0].name().to_string(), "get_mystic_number");
+        assert_eq!(item_mod.fns()[0].arg_count(), 0);
+        assert_eq!(
+            item_mod.fns()[0].return_type().unwrap(),
+            &syn::parse2::<syn::Type>(quote! { INT }).unwrap()
+        );
+    }
+
+    #[test]
+    #[cfg(feature = "metadata")]
     fn one_factory_fn_with_comments_module() {
         let input_tokens: TokenStream = quote! {
             pub mod one_fn {
@@ -150,9 +176,9 @@ mod module_tests {
         assert!(item_mod.fns().is_empty());
         assert!(item_mod.consts().is_empty());
         assert_eq!(item_mod.sub_modules().len(), 1);
-        assert_eq!(&item_mod.sub_modules()[0].consts()[0].0, "MYSTIC_NUMBER");
+        assert_eq!(&item_mod.sub_modules()[0].consts()[0].name, "MYSTIC_NUMBER");
         assert_eq!(
-            item_mod.sub_modules()[0].consts()[0].2,
+            item_mod.sub_modules()[0].consts()[0].expr,
             syn::parse2::<syn::Expr>(quote! { 42 }).unwrap()
         );
     }
@@ -211,9 +237,9 @@ mod module_tests {
         let item_mod = syn::parse2::<Module>(input_tokens).unwrap();
         assert!(item_mod.fns().is_empty());
         assert_eq!(item_mod.consts().len(), 1);
-        assert_eq!(&item_mod.consts()[0].0, "MYSTIC_NUMBER");
+        assert_eq!(&item_mod.consts()[0].name, "MYSTIC_NUMBER");
         assert_eq!(
-            item_mod.consts()[0].2,
+            item_mod.consts()[0].expr,
             syn::parse2::<syn::Expr>(quote! { 42 }).unwrap()
         );
     }
@@ -386,6 +412,14 @@ mod generate_tests {
 
         let expected_tokens = quote! {
             pub mod one_fn {
+                /// This is a doc-comment.
+                /// Another line.
+                /** block doc-comment */
+                // Regular comment
+                /// Final line.
+                /** doc-comment
+                    in multiple lines
+                 */
                 pub fn get_mystic_number() -> INT {
                     42
                 }
@@ -401,8 +435,13 @@ mod generate_tests {
                 #[allow(unused_mut)]
                 pub fn rhai_generate_into_module(m: &mut Module, flatten: bool) {
                     m.set_fn_with_comments("get_mystic_number", FnNamespace::Internal, FnAccess::Public,
-                             Some(get_mystic_number_token::PARAM_NAMES), &[], &["/// This is a doc-comment.","/// Another line.","/// block doc-comment ","/// Final line.","/** doc-comment\n                    in multiple lines\n                 */"],
-                             get_mystic_number_token().into());
+                             Some(get_mystic_number_token::PARAM_NAMES), &[], &[
+                                 "/// This is a doc-comment.",
+                                 "/// Another line.",
+                                 "/// block doc-comment ",
+                                 "/// Final line.",
+                                 "/** doc-comment\n                    in multiple lines\n                 */"
+                             ], get_mystic_number_token().into());
                     if flatten {} else {}
                 }
                 #[allow(non_camel_case_types)]
@@ -739,7 +778,13 @@ mod generate_tests {
                 #[derive(Debug, Clone)]
                 pub struct Foo(pub INT);
 
+                pub type Hello = Foo;
+
                 pub const MYSTIC_NUMBER: Foo = Foo(42);
+
+                pub fn get_mystic_number(x: &mut Hello) -> INT {
+                    x.0
+                }
             }
         };
 
@@ -748,7 +793,13 @@ mod generate_tests {
                 #[derive(Debug, Clone)]
                 pub struct Foo(pub INT);
 
+                pub type Hello = Foo;
+
                 pub const MYSTIC_NUMBER: Foo = Foo(42);
+
+                pub fn get_mystic_number(x: &mut Hello) -> INT {
+                    x.0
+                }
                 #[allow(unused_imports)]
                 use super::*;
 
@@ -760,9 +811,32 @@ mod generate_tests {
                 }
                 #[allow(unused_mut)]
                 pub fn rhai_generate_into_module(m: &mut Module, flatten: bool) {
+                    m.set_fn("get_mystic_number", FnNamespace::Internal, FnAccess::Public,
+                             Some(get_mystic_number_token::PARAM_NAMES), &[TypeId::of::<Hello>()],
+                             get_mystic_number_token().into());
                     m.set_var("MYSTIC_NUMBER", MYSTIC_NUMBER);
+                    m.set_custom_type::<Foo>("Hello");
                     if flatten {} else {}
                 }
+
+                #[allow(non_camel_case_types)]
+                pub struct get_mystic_number_token();
+                impl get_mystic_number_token {
+                    pub const PARAM_NAMES: &'static [&'static str] = &["x: &mut Hello", "INT"];
+                    #[inline(always)] pub fn param_types() -> [TypeId; 1usize] { [TypeId::of::<Hello>()] }
+                }
+                impl PluginFunction for get_mystic_number_token {
+                    #[inline(always)]
+                    fn call(&self, context: NativeCallContext, args: &mut [&mut Dynamic]) -> RhaiResult {
+                        if args[0usize].is_read_only() {
+                            return Err(EvalAltResult::ErrorAssignmentToConstant("x".to_string(), Position::NONE).into());
+                        }
+                        let arg0 = &mut args[0usize].write_lock::<Hello>().unwrap();
+                        Ok(Dynamic::from(get_mystic_number(arg0)))
+                    }
+
+                    #[inline(always)] fn is_method_call(&self) -> bool { true }
+                }
             }
         };
 
